@@ -3,7 +3,7 @@
 
  Lincoln Stein <lincoln.stein@gmail.com>
  Ben Faga <ben.faga@gmail.com>
- $Id: controller.js,v 1.95 2009/05/22 21:37:09 lstein Exp $
+ $Id: controller.js,v 1.98 2009/06/05 18:55:11 lstein Exp $
 
 Indentation courtesy of Emacs javascript-mode 
 (http://mihai.bazon.net/projects/emacs-javascript-mode/javascript.el)
@@ -225,7 +225,7 @@ var GBrowseController = Class.create({
 
   // Update Section Methods *****************************************
   update_sections:
-  function(section_names, param_str, scroll_there) {
+  function(section_names, param_str, scroll_there, spin) {
 
     if (param_str==null){
         param_str = '';
@@ -233,10 +233,14 @@ var GBrowseController = Class.create({
     if (scroll_there==null) {
         scroll_there=false;
     }
+    if (spin == null) {
+        spin = false;
+    }
 
     var request_str = "update_sections=1" + param_str;
     for (var i = 0; i < section_names.length; i++) {
-      $(section_names[i]).innerHTML="<img src='/gbrowse2/images/spinner.gif' alt='loading...' />";
+      if (spin)
+         $(section_names[i]).innerHTML="<img src='/gbrowse2/images/spinner.gif' alt='loading...' />";
       request_str += "&section_names="+section_names[i];
     }
 
@@ -621,7 +625,7 @@ var GBrowseController = Class.create({
           if ($(track_div_id) != null){
             actually_remove(track_div_id);
           }
-          Controller.update_sections(new Array(track_listing_id));
+          Controller.update_sections(new Array(track_listing_id),null,null,true);
         }
       } // end onSuccess
     });
@@ -634,7 +638,7 @@ var GBrowseController = Class.create({
     new Ajax.Request(document.URL,{
       method:     'post',
       parameters: form_element.serialize() +"&"+ $H({
-            filter_subtrack:  track_id,
+            filter_subtrack:  track_id
           }).toQueryString(),
       onSuccess: function(transport) {
         Balloon.prototype.hideTooltip(1);
@@ -648,7 +652,7 @@ var GBrowseController = Class.create({
   configure_plugin:
   function(div_id) {
     var plugin_base  = document.pluginform.plugin.value;
-    this.update_sections(new Array(div_id), '&plugin_base='+plugin_base);
+    this.update_sections(new Array(div_id), '&plugin_base='+plugin_base,null,null,true);
     new Effect.ScrollTo(div_id);
   },
 
@@ -676,13 +680,13 @@ var GBrowseController = Class.create({
         }
         else if (plugin_type == 'filter') {
           Controller.update_coordinates("reload segment");
-	  Controller.update_sections(new Array(track_listing_id),'',1);
+	  Controller.update_sections(new Array(track_listing_id),'',1,false);
 	}
         else if (plugin_type == 'highlighter') {
           Controller.update_coordinates("reload segment");
         }
 	else if (plugin_type == 'trackfilter') {
-	  Controller.update_sections(new Array(track_listing_id),'',1);
+	  Controller.update_sections(new Array(track_listing_id),'',1,false);
 	}
       } // end onSuccess
     });
@@ -695,7 +699,7 @@ var GBrowseController = Class.create({
       var track_name = select_box.options[select_box.selectedIndex].attributes.getNamedItem('track_name').value;
 
       this.add_track(track_name);
-      Controller.update_sections(new Array(track_listing_id));
+      Controller.update_sections(new Array(track_listing_id),null,null,false);
     }
     else if (plugin_type == 'dumper'){
       var loc_str = "?plugin="+plugin_base+";plugin_action="+encodeURI(plugin_action);
@@ -720,7 +724,7 @@ var GBrowseController = Class.create({
 
   edit_new_file:
   function() {
-    Controller.update_sections(new Array(external_utility_div_id), '&new_edit_file=1',true);
+    Controller.update_sections(new Array(external_utility_div_id), '&new_edit_file=1',true,true);
   },
 
   edit_upload:
@@ -729,7 +733,7 @@ var GBrowseController = Class.create({
     var basename = gbtrack!=null ? gbtrack.track_name : edit_file;
     visibility('upload_tracks_panel',1);
     Controller.update_sections(new Array(external_utility_div_id), 
-   	    '&edit_file='+basename,true);
+   	    '&edit_file='+basename,true,true);
   },
 
   commit_file_edit:
@@ -770,19 +774,19 @@ var GBrowseController = Class.create({
 
 	tracks_to_update.each(function(id) { 
 	   Controller.rerender_track(id,true);
-	   Controller.update_sections(new Array(external_listing_id));
+	   Controller.update_sections(new Array(external_listing_id),null,null,true);
 	});
 
 	tracks_to_delete.each(function(id) { 
 	   var gbtrack = current_tracks.get(id);
 	   actually_remove(gbtrack.track_div_id);
 	   Controller.unregister_gbtrack(gbtrack);
-	   Controller.update_sections(new Array(track_listing_id,external_listing_id));
+	   Controller.update_sections(new Array(track_listing_id,external_listing_id),null,null,false);
 	});
 
 	if (tracks_to_add.length > 0)
           Controller.add_track(edited_file, function(){
-            Controller.update_sections(new Array(track_listing_id,external_listing_id));
+            Controller.update_sections(new Array(track_listing_id,external_listing_id),null,null,false);
         },true);	
 
       } // end onSuccess
@@ -804,7 +808,7 @@ var GBrowseController = Class.create({
         Controller.each_track(file_name,function(gbtrack) {
 	      actually_remove(gbtrack.track_div_id);
           });
-        Controller.update_sections(new Array(track_listing_id,external_listing_id));
+        Controller.update_sections(new Array(track_listing_id,external_listing_id),null,null,true);
         Controller.unregister_track(file_name);
       } // end onSuccess
     });
@@ -829,7 +833,7 @@ var GBrowseController = Class.create({
         var url_created = results.url_created;
         if ( 1 == url_created ){
           Controller.add_track(eurl, function(){
-            Controller.update_sections(new Array(track_listing_id,external_listing_id));
+            Controller.update_sections(new Array(track_listing_id,external_listing_id),null,null,true);
           })
         } else
 	  Controller.each_track(eurl,function(gbtrack) {
